@@ -59,4 +59,4 @@ function Dot(runner) {
  * Inherit from `Base.prototype`.
  */
 
-Dot.prototype.__proto__ = Base.prototype;
+Object.setPrototypeOf(Dot.prototype, Base.prototype);
